"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const preset = (_api, { esm = false, node = false, graphql = false, dev = process.env.NODE_NEV === 'development', env = true, typescript = true, react = false, }) => {
    var _a;
    if (!process.env.NODE_ENV) {
        process.env.NODE_ENV = 'development';
    }
    if (env === true)
        env = {};
    if (typescript === true)
        typescript = {};
    if (react === true)
        react = {};
    const plugins = [
        ['@babel/plugin-proposal-decorators', { legacy: true }],
        ['@babel/plugin-proposal-class-properties', { loose: true }],
    ];
    const presets = [];
    if (env) {
        const envOptions = Object.assign({ loose: true, modules: esm ? false : 'commonjs', shippedProposals: true }, env);
        if (!env.targets) {
            if (node)
                envOptions.targets = constants_1.NODE_TARGET;
            if (!node && dev)
                envOptions.targets = constants_1.WEB_TARGET_DEV;
            if (!node && !dev)
                envOptions.targets = constants_1.WEB_TARGET;
        }
        envOptions.bugfixes =
            typeof envOptions.targets === 'object' &&
                !Array.isArray(envOptions.targets) &&
                !!((_a = envOptions.targets) === null || _a === void 0 ? void 0 : _a.esmodules);
        if (process.env.NODE_ENV === 'test') {
            envOptions.modules = 'commonjs';
            envOptions.targets = { node: 'current' };
            plugins.push('babel-plugin-dynamic-import-node');
        }
        presets.push(['@babel/preset-env', envOptions]);
    }
    if (typescript) {
        const typescriptOptions = {};
        presets.push(['@babel/preset-typescript', typescriptOptions]);
        plugins.push('babel-plugin-transform-typescript-metadata');
    }
    if (react) {
        const reactOptions = Object.assign({}, react);
        presets.push(['@babel/preset-react', reactOptions]);
    }
    if (graphql) {
        plugins.push('babel-plugin-graphql-tag');
    }
    return {
        plugins,
        presets,
    };
};
exports.default = preset;
